# OctoPrint-HeaderAnnouncements
In a shared environment like a maker space or lab, it can be useful to be able to notify users of upcoming changes, maintenance, procedures, etc.  This plugin allows you to set a header that will be displayed at the top of the page for users to see.

## Setup

Install via the bundled [Plugin Manager](https://docs.octoprint.org/en/master/bundledplugins/pluginmanager.html)
or manually using this URL:

    https://github.com/wwsean08/OctoPrint-HeaderAnnouncements/archive/master.zip

## Configuration

* Announcement: The announcement to display.  If you update this after someone has loaded the page, they will receive the new announcement within 1 minute replacing the existing one.
